==> ejc-budgetmanage-impl-3.0.0-20220404.033202-49-sources.jar: com/ejianc/business/bedget/vo/ConsdrawbudgetdetailVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 施工图预算子表
 * 
 * @author generator
 * 
 */
public class ConsdrawbudgetdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String sort; // 序号
    private java.lang.String section; // 区段
    private java.lang.String subitemCode; // 子目编码
    private java.lang.String subitemName; // 子目名称
    private java.lang.String characterDescrip; // 子目特征描述
    private java.lang.String estimateUnit; // 计量单位
    private java.math.BigDecimal engineeQuatity; // 工程量
    private java.math.BigDecimal unitLaborCost; // 人工费(单价)
    private java.math.BigDecimal unitMaterialCost; // 材料费(单价)
    private java.math.BigDecimal unitMachineryCost; // 机械费(单价)
    private java.math.BigDecimal unitBusinessManagerCost; // 企业管理费(单价)
    private java.math.BigDecimal unitProfit; // 利润(单价)
    private java.math.BigDecimal comprehensiveUnitPrice; // 综合单价
    private java.math.BigDecimal totalLaborCost; // 人工费(综合)
    private java.math.BigDecimal totalMaterialCost; // 材料费(综合)
    private java.math.BigDecimal totalMachineryCost; // 机械费(综合)
    private java.math.BigDecimal totalBusinessManagerCost; // 企业管理费(综合)
    private java.math.BigDecimal totalProfit; // 利润(综合)
    private java.math.BigDecimal comprehensiveTotalPrice; // 综合总价
    private java.math.BigDecimal sumTotalPrice; // 合价
    private java.math.BigDecimal socialSecurity; // 社保
    private java.math.BigDecimal housing; // 住房
    private java.math.BigDecimal reserved1; // 预留1
    private java.math.BigDecimal reserved2; // 预留2
    private java.math.BigDecimal reserved3; // 预留3
    private java.math.BigDecimal tax; // 税金
    private java.math.BigDecimal provisionalEstimate; // 暂估价
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private String innercode; // 内码
    private String errorMsg; // 导入错误信息

    private List<ConsdrawbudgetdetailVO> children = new ArrayList<>();
    public List<ConsdrawbudgetdetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<ConsdrawbudgetdetailVO> children) {
        this.children = children;
    }
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 区段
     */
    public java.lang.String getSection() {
        return section;
    }

    /**
     * 区段
     */
    public void setSection(java.lang.String section) {
        this.section = section;
    }
    /**
     * 子目编码
     */
    public java.lang.String getSubitemCode() {
        return subitemCode;
    }

    /**
     * 子目编码
     */
    public void setSubitemCode(java.lang.String subitemCode) {
        this.subitemCode = subitemCode;
    }
    /**
     * 子目名称
     */
    public java.lang.String getSubitemName() {
        return subitemName;
    }

    /**
     * 子目名称
     */
    public void setSubitemName(java.lang.String subitemName) {
        this.subitemName = subitemName;
    }
    /**
     * 子目特征描述
     */
    public java.lang.String getCharacterDescrip() {
        return characterDescrip;
    }

    /**
     * 子目特征描述
     */
    public void setCharacterDescrip(java.lang.String characterDescrip) {
        this.characterDescrip = characterDescrip;
    }
    /**
     * 计量单位
     */
    public java.lang.String getEstimateUnit() {
        return estimateUnit;
    }

    /**
     * 计量单位
     */
    public void setEstimateUnit(java.lang.String estimateUnit) {
        this.estimateUnit = estimateUnit;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getEngineeQuatity() {
        return engineeQuatity;
    }

    /**
     * 工程量
     */
    public void setEngineeQuatity(java.math.BigDecimal engineeQuatity) {
        this.engineeQuatity = engineeQuatity;
    }
    /**
     * 人工费(单价)
     */
    public java.math.BigDecimal getUnitLaborCost() {
        return unitLaborCost;
    }

    /**
     * 人工费(单价)
     */
    public void setUnitLaborCost(java.math.BigDecimal unitLaborCost) {
        this.unitLaborCost = unitLaborCost;
    }
    /**
     * 材料费(单价)
     */
    public java.math.BigDecimal getUnitMaterialCost() {
        return unitMaterialCost;
    }

    /**
     * 材料费(单价)
     */
    public void setUnitMaterialCost(java.math.BigDecimal unitMaterialCost) {
        this.unitMaterialCost = unitMaterialCost;
    }
    /**
     * 机械费(单价)
     */
    public java.math.BigDecimal getUnitMachineryCost() {
        return unitMachineryCost;
    }

    /**
     * 机械费(单价)
     */
    public void setUnitMachineryCost(java.math.BigDecimal unitMachineryCost) {
        this.unitMachineryCost = unitMachineryCost;
    }
    /**
     * 企业管理费(单价)
     */
    public java.math.BigDecimal getUnitBusinessManagerCost() {
        return unitBusinessManagerCost;
    }

    /**
     * 企业管理费(单价)
     */
    public void setUnitBusinessManagerCost(java.math.BigDecimal unitBusinessManagerCost) {
        this.unitBusinessManagerCost = unitBusinessManagerCost;
    }
    /**
     * 利润(单价)
     */
    public java.math.BigDecimal getUnitProfit() {
        return unitProfit;
    }

    /**
     * 利润(单价)
     */
    public void setUnitProfit(java.math.BigDecimal unitProfit) {
        this.unitProfit = unitProfit;
    }
    /**
     * 综合单价
     */
    public java.math.BigDecimal getComprehensiveUnitPrice() {
        return comprehensiveUnitPrice;
    }

    /**
     * 综合单价
     */
    public void setComprehensiveUnitPrice(java.math.BigDecimal comprehensiveUnitPrice) {
        this.comprehensiveUnitPrice = comprehensiveUnitPrice;
    }
    /**
     * 人工费(综合)
     */
    public java.math.BigDecimal getTotalLaborCost() {
        return totalLaborCost;
    }

    /**
     * 人工费(综合)
     */
    public void setTotalLaborCost(java.math.BigDecimal totalLaborCost) {
        this.totalLaborCost = totalLaborCost;
    }
    /**
     * 材料费(综合)
     */
    public java.math.BigDecimal getTotalMaterialCost() {
        return totalMaterialCost;
    }

    /**
     * 材料费(综合)
     */
    public void setTotalMaterialCost(java.math.BigDecimal totalMaterialCost) {
        this.totalMaterialCost = totalMaterialCost;
    }
    /**
     * 机械费(综合)
     */
    public java.math.BigDecimal getTotalMachineryCost() {
        return totalMachineryCost;
    }

    /**
     * 机械费(综合)
     */
    public void setTotalMachineryCost(java.math.BigDecimal totalMachineryCost) {
        this.totalMachineryCost = totalMachineryCost;
    }
    /**
     * 企业管理费(综合)
     */
    public java.math.BigDecimal getTotalBusinessManagerCost() {
        return totalBusinessManagerCost;
    }

    /**
     * 企业管理费(综合)
     */
    public void setTotalBusinessManagerCost(java.math.BigDecimal totalBusinessManagerCost) {
        this.totalBusinessManagerCost = totalBusinessManagerCost;
    }
    /**
     * 利润(综合)
     */
    public java.math.BigDecimal getTotalProfit() {
        return totalProfit;
    }

    /**
     * 利润(综合)
     */
    public void setTotalProfit(java.math.BigDecimal totalProfit) {
        this.totalProfit = totalProfit;
    }
    /**
     * 综合总价
     */
    public java.math.BigDecimal getComprehensiveTotalPrice() {
        return comprehensiveTotalPrice;
    }

    /**
     * 综合总价
     */
    public void setComprehensiveTotalPrice(java.math.BigDecimal comprehensiveTotalPrice) {
        this.comprehensiveTotalPrice = comprehensiveTotalPrice;
    }
    /**
     * 合价
     */
    public java.math.BigDecimal getSumTotalPrice() {
        return sumTotalPrice;
    }

    /**
     * 合价
     */
    public void setSumTotalPrice(java.math.BigDecimal sumTotalPrice) {
        this.sumTotalPrice = sumTotalPrice;
    }
    /**
     * 社保
     */
    public java.math.BigDecimal getSocialSecurity() {
        return socialSecurity;
    }

    /**
     * 社保
     */
    public void setSocialSecurity(java.math.BigDecimal socialSecurity) {
        this.socialSecurity = socialSecurity;
    }
    /**
     * 住房
     */
    public java.math.BigDecimal getHousing() {
        return housing;
    }

    /**
     * 住房
     */
    public void setHousing(java.math.BigDecimal housing) {
        this.housing = housing;
    }
    /**
     * 预留1
     */
    public java.math.BigDecimal getReserved1() {
        return reserved1;
    }

    /**
     * 预留1
     */
    public void setReserved1(java.math.BigDecimal reserved1) {
        this.reserved1 = reserved1;
    }
    /**
     * 预留2
     */
    public java.math.BigDecimal getReserved2() {
        return reserved2;
    }

    /**
     * 预留2
     */
    public void setReserved2(java.math.BigDecimal reserved2) {
        this.reserved2 = reserved2;
    }
    /**
     * 预留3
     */
    public java.math.BigDecimal getReserved3() {
        return reserved3;
    }

    /**
     * 预留3
     */
    public void setReserved3(java.math.BigDecimal reserved3) {
        this.reserved3 = reserved3;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 暂估价
     */
    public java.math.BigDecimal getProvisionalEstimate() {
        return provisionalEstimate;
    }

    /**
     * 暂估价
     */
    public void setProvisionalEstimate(java.math.BigDecimal provisionalEstimate) {
        this.provisionalEstimate = provisionalEstimate;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }
}

==> ejc-budgetmanage-impl-3.0.0-20220407.084509-69-sources.jar: com/ejianc/business/bedget/vo/ConsdrawbudgetdetailVO.java <==
package com.ejianc.business.bedget.vo;

import java.util.List;
import java.util.ArrayList;
import com.ejianc.framework.skeleton.template.BaseVO;


/**
 * 施工图预算子表
 * 
 * @author generator
 * 
 */
public class ConsdrawbudgetdetailVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.Long mid; // 主表id
    private java.lang.String tid;
    private java.lang.String tpid;
    private java.lang.String sort; // 序号
    private java.lang.String section; // 区段
    private java.lang.String subitemCode; // 子目编码
    private java.lang.String subitemName; // 子目名称
    private java.lang.String characterDescrip; // 子目特征描述
    private java.lang.String estimateUnit; // 计量单位
    private java.math.BigDecimal engineeQuatity; // 工程量
    private java.math.BigDecimal unitLaborCost; // 人工费(单价)
    private java.math.BigDecimal unitMaterialCost; // 材料费(单价)
    private java.math.BigDecimal unitMachineryCost; // 机械费(单价)
    private java.math.BigDecimal unitBusinessManagerCost; // 企业管理费(单价)
    private java.math.BigDecimal unitProfit; // 利润(单价)
    private java.math.BigDecimal comprehensiveUnitPrice; // 综合单价
    private java.math.BigDecimal totalLaborCost; // 人工费(综合)
    private java.math.BigDecimal totalMaterialCost; // 材料费(综合)
    private java.math.BigDecimal totalMachineryCost; // 机械费(综合)
    private java.math.BigDecimal totalBusinessManagerCost; // 企业管理费(综合)
    private java.math.BigDecimal totalProfit; // 利润(综合)
    private java.math.BigDecimal comprehensiveTotalPrice; // 综合总价
    private java.math.BigDecimal sumTotalPrice; // 合价
    private java.math.BigDecimal socialSecurity; // 社保
    private java.math.BigDecimal housing; // 住房
    private java.math.BigDecimal reserved1; // 预留1
    private java.math.BigDecimal reserved2; // 预留2
    private java.math.BigDecimal reserved3; // 预留3
    private java.math.BigDecimal tax; // 税金
    private java.math.BigDecimal provisionalEstimate; // 暂估价
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    private String innercode; // 内码
    private String errorMsg; // 导入错误信息

    private boolean isAdd;//是否已汇总子级

    private List<ConsdrawbudgetdetailVO> children = new ArrayList<>();
    public List<ConsdrawbudgetdetailVO> getChildren() {
        return children;
    }

    public void setChildren(List<ConsdrawbudgetdetailVO> children) {
        this.children = children;
    }
    

    /**
     * 主表id
     */
    public java.lang.Long getMid() {
        return mid;
    }

    /**
     * 主表id
     */
    public void setMid(java.lang.Long mid) {
        this.mid = mid;
    }

    public String getTid() {
        return tid;
    }

    public void setTid(String tid) {
        this.tid = tid;
    }

    public String getTpid() {
        return tpid;
    }

    public void setTpid(String tpid) {
        this.tpid = tpid;
    }
    /**
     * 序号
     */
    public java.lang.String getSort() {
        return sort;
    }

    /**
     * 序号
     */
    public void setSort(java.lang.String sort) {
        this.sort = sort;
    }
    /**
     * 区段
     */
    public java.lang.String getSection() {
        return section;
    }

    /**
     * 区段
     */
    public void setSection(java.lang.String section) {
        this.section = section;
    }
    /**
     * 子目编码
     */
    public java.lang.String getSubitemCode() {
        return subitemCode;
    }

    /**
     * 子目编码
     */
    public void setSubitemCode(java.lang.String subitemCode) {
        this.subitemCode = subitemCode;
    }
    /**
     * 子目名称
     */
    public java.lang.String getSubitemName() {
        return subitemName;
    }

    /**
     * 子目名称
     */
    public void setSubitemName(java.lang.String subitemName) {
        this.subitemName = subitemName;
    }
    /**
     * 子目特征描述
     */
    public java.lang.String getCharacterDescrip() {
        return characterDescrip;
    }

    /**
     * 子目特征描述
     */
    public void setCharacterDescrip(java.lang.String characterDescrip) {
        this.characterDescrip = characterDescrip;
    }
    /**
     * 计量单位
     */
    public java.lang.String getEstimateUnit() {
        return estimateUnit;
    }

    /**
     * 计量单位
     */
    public void setEstimateUnit(java.lang.String estimateUnit) {
        this.estimateUnit = estimateUnit;
    }
    /**
     * 工程量
     */
    public java.math.BigDecimal getEngineeQuatity() {
        return engineeQuatity;
    }

    /**
     * 工程量
     */
    public void setEngineeQuatity(java.math.BigDecimal engineeQuatity) {
        this.engineeQuatity = engineeQuatity;
    }
    /**
     * 人工费(单价)
     */
    public java.math.BigDecimal getUnitLaborCost() {
        return unitLaborCost;
    }

    /**
     * 人工费(单价)
     */
    public void setUnitLaborCost(java.math.BigDecimal unitLaborCost) {
        this.unitLaborCost = unitLaborCost;
    }
    /**
     * 材料费(单价)
     */
    public java.math.BigDecimal getUnitMaterialCost() {
        return unitMaterialCost;
    }

    /**
     * 材料费(单价)
     */
    public void setUnitMaterialCost(java.math.BigDecimal unitMaterialCost) {
        this.unitMaterialCost = unitMaterialCost;
    }
    /**
     * 机械费(单价)
     */
    public java.math.BigDecimal getUnitMachineryCost() {
        return unitMachineryCost;
    }

    /**
     * 机械费(单价)
     */
    public void setUnitMachineryCost(java.math.BigDecimal unitMachineryCost) {
        this.unitMachineryCost = unitMachineryCost;
    }
    /**
     * 企业管理费(单价)
     */
    public java.math.BigDecimal getUnitBusinessManagerCost() {
        return unitBusinessManagerCost;
    }

    /**
     * 企业管理费(单价)
     */
    public void setUnitBusinessManagerCost(java.math.BigDecimal unitBusinessManagerCost) {
        this.unitBusinessManagerCost = unitBusinessManagerCost;
    }
    /**
     * 利润(单价)
     */
    public java.math.BigDecimal getUnitProfit() {
        return unitProfit;
    }

    /**
     * 利润(单价)
     */
    public void setUnitProfit(java.math.BigDecimal unitProfit) {
        this.unitProfit = unitProfit;
    }
    /**
     * 综合单价
     */
    public java.math.BigDecimal getComprehensiveUnitPrice() {
        return comprehensiveUnitPrice;
    }

    /**
     * 综合单价
     */
    public void setComprehensiveUnitPrice(java.math.BigDecimal comprehensiveUnitPrice) {
        this.comprehensiveUnitPrice = comprehensiveUnitPrice;
    }
    /**
     * 人工费(综合)
     */
    public java.math.BigDecimal getTotalLaborCost() {
        return totalLaborCost;
    }

    /**
     * 人工费(综合)
     */
    public void setTotalLaborCost(java.math.BigDecimal totalLaborCost) {
        this.totalLaborCost = totalLaborCost;
    }
    /**
     * 材料费(综合)
     */
    public java.math.BigDecimal getTotalMaterialCost() {
        return totalMaterialCost;
    }

    /**
     * 材料费(综合)
     */
    public void setTotalMaterialCost(java.math.BigDecimal totalMaterialCost) {
        this.totalMaterialCost = totalMaterialCost;
    }
    /**
     * 机械费(综合)
     */
    public java.math.BigDecimal getTotalMachineryCost() {
        return totalMachineryCost;
    }

    /**
     * 机械费(综合)
     */
    public void setTotalMachineryCost(java.math.BigDecimal totalMachineryCost) {
        this.totalMachineryCost = totalMachineryCost;
    }
    /**
     * 企业管理费(综合)
     */
    public java.math.BigDecimal getTotalBusinessManagerCost() {
        return totalBusinessManagerCost;
    }

    /**
     * 企业管理费(综合)
     */
    public void setTotalBusinessManagerCost(java.math.BigDecimal totalBusinessManagerCost) {
        this.totalBusinessManagerCost = totalBusinessManagerCost;
    }
    /**
     * 利润(综合)
     */
    public java.math.BigDecimal getTotalProfit() {
        return totalProfit;
    }

    /**
     * 利润(综合)
     */
    public void setTotalProfit(java.math.BigDecimal totalProfit) {
        this.totalProfit = totalProfit;
    }
    /**
     * 综合总价
     */
    public java.math.BigDecimal getComprehensiveTotalPrice() {
        return comprehensiveTotalPrice;
    }

    /**
     * 综合总价
     */
    public void setComprehensiveTotalPrice(java.math.BigDecimal comprehensiveTotalPrice) {
        this.comprehensiveTotalPrice = comprehensiveTotalPrice;
    }
    /**
     * 合价
     */
    public java.math.BigDecimal getSumTotalPrice() {
        return sumTotalPrice;
    }

    /**
     * 合价
     */
    public void setSumTotalPrice(java.math.BigDecimal sumTotalPrice) {
        this.sumTotalPrice = sumTotalPrice;
    }
    /**
     * 社保
     */
    public java.math.BigDecimal getSocialSecurity() {
        return socialSecurity;
    }

    /**
     * 社保
     */
    public void setSocialSecurity(java.math.BigDecimal socialSecurity) {
        this.socialSecurity = socialSecurity;
    }
    /**
     * 住房
     */
    public java.math.BigDecimal getHousing() {
        return housing;
    }

    /**
     * 住房
     */
    public void setHousing(java.math.BigDecimal housing) {
        this.housing = housing;
    }
    /**
     * 预留1
     */
    public java.math.BigDecimal getReserved1() {
        return reserved1;
    }

    /**
     * 预留1
     */
    public void setReserved1(java.math.BigDecimal reserved1) {
        this.reserved1 = reserved1;
    }
    /**
     * 预留2
     */
    public java.math.BigDecimal getReserved2() {
        return reserved2;
    }

    /**
     * 预留2
     */
    public void setReserved2(java.math.BigDecimal reserved2) {
        this.reserved2 = reserved2;
    }
    /**
     * 预留3
     */
    public java.math.BigDecimal getReserved3() {
        return reserved3;
    }

    /**
     * 预留3
     */
    public void setReserved3(java.math.BigDecimal reserved3) {
        this.reserved3 = reserved3;
    }
    /**
     * 税金
     */
    public java.math.BigDecimal getTax() {
        return tax;
    }

    /**
     * 税金
     */
    public void setTax(java.math.BigDecimal tax) {
        this.tax = tax;
    }
    /**
     * 暂估价
     */
    public java.math.BigDecimal getProvisionalEstimate() {
        return provisionalEstimate;
    }

    /**
     * 暂估价
     */
    public void setProvisionalEstimate(java.math.BigDecimal provisionalEstimate) {
        this.provisionalEstimate = provisionalEstimate;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    public String getInnercode() {
        return innercode;
    }

    public void setInnercode(String innercode) {
        this.innercode = innercode;
    }

    public String getErrorMsg() {
        return errorMsg;
    }

    public void setErrorMsg(String errorMsg) {
        this.errorMsg = errorMsg;
    }

    public boolean isAdd() {
        return isAdd;
    }

    public void setAdd(boolean add) {
        isAdd = add;
    }
}
